import react from '@vitejs/plugin-react-swc';
import UnoCSS from 'unocss/vite';
import { defineConfig, loadEnv, PluginOption } from 'vite';
import pluginImport from 'vite-plugin-importer';
import svgr from 'vite-plugin-svgr';
import tsconfigPaths from 'vite-tsconfig-paths';

/// <reference types="vite-plugin-svgr/client" />

// https://vite.dev/config/
export default defineConfig(({ mode }) => {
  const config = loadEnv(mode, './');
  return {
    resolve: {
      alias: [],
    },
    plugins: [
      svgr() as PluginOption,
      react(),
      UnoCSS(),
      pluginImport({
        libraryName: '@nutui/nutui-react',
        libraryDirectory: 'dist/esm',
        style: (path: string) => `${path}/style/css`,
      }),
      tsconfigPaths() as PluginOption,
    ],
    css: {
      // modules: {
      //   hashPrefix: 'prefix',
      //   generateScopedName: '[name]__[local]__[hash:base64:5]',
      // },
      preprocessorOptions: {
        sass: {
          api: 'modern',
          additionalData: `@nutui/nutui-react/dist/styles/variables.scss`,
          silenceDeprecations: ['legacy-js-api', 'color-functions'],
        },
        scss: {
          api: 'modern',
          silenceDeprecations: ['legacy-js-api'],
        },
      },
    },
    server: {
      proxy: {
        '/api': {
          target: config.VITE_BASIC_URL,
          changeOrigin: true,
          secure: false,
        },
      },
    },
  };
});
